<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="147"/>
        <source>GTK themes</source>
        <translation>GTK témy</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="148"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; bol prepísaný.&lt;/p&gt;&lt;p&gt;Kópiu predošlých nastavení nájdete v &apos;%2&apos;&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Predvolené písmo pre používateľské rozhranie</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Názov prísma:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Štýl:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Veľkosť bodu:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normálne</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Hrubé</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Hrubé kurzíva</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Nasledujúce nastavenia ovplyvnia iba novo spustené aplikácie</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Použiť vyhladzovanie písma</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Vyhladzovanie písma:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Žiaden</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Ľahký</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Stredný</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Plné</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Vyhladzovanie písma</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Rozlíšenie (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Automatické vyhladzovanie písma</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Subpixelové vyhladzovanie:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Nastavenie vzhľadu prostredia LXQt</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Téma ikon</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>Rozšírenie KDE pre XDG témy ikon -&gt; Nasledujte schému farieb</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Farebné symboly používajúce štýl ovládacích prvkov (paleta)</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>Téma LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation>Užívateľská zmena pozadia</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Nastavenie vzhľadu prostredia LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Widget Style</source>
        <translation>Štýl widegtov</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>Icons Theme</source>
        <translation>Téma ikon</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>LXQt Theme</source>
        <translation>Téma LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="106"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Štýl widgetov</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="42"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>Nastavenie témy GTK (Konfiguračný súbor GTK bude prepísaný!)</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="62"/>
        <source>GTK 3 Theme</source>
        <translation>Téma GTK 3</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="72"/>
        <source>GTK 2 Theme</source>
        <translation>Téma GTK 2</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="82"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Ak sa pokúšate nastaviť GTK motív, buď vyberte zo zoznamu podobný štýl / tému (ak je k dispozícii), alebo vyberte štýl gtk2 Qt (ak je k dispozícii).

Uistite sa, že &apos;xsettingsd&apos; je nainštalovaný.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="99"/>
        <source>Toolbar button style:</source>
        <translation>Štýl tlačidiel panela:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="107"/>
        <source>Only display the icon</source>
        <translation>Zobraziť iba ikony</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>Only display the text</source>
        <translation>Zobraziť iba text</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="117"/>
        <source>The text appears beside the icon</source>
        <translation>Text vedľa ikôn</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>The text appears under the icon</source>
        <translation>Text pod ikonami</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="127"/>
        <source>Default</source>
        <translation>Štandardné</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="135"/>
        <source>Activate item on single click</source>
        <translation>Aktivovať jednoduchým kliknutím</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="145"/>
        <source>Qt Style</source>
        <translation>Štýl Qt</translation>
    </message>
</context>
</TS>
